@@ -115,18 +115,18 @@ case $os in
 esac
 
 # bash will eat your spaces, so let's array. see http://mywiki.wooledge.org/BashFAQ/050 for more fun.
-params=("--user" "puppetdb" "--group" "puppetdb" "--chdir" "$dir" "--realname" "puppetdb" "--operating-system" "$os" "--name" "openvoxdb" "--package-version" "7.21.2" "--release" "1" "--platform-version" "7")
+params=("--user" "puppetdb" "--group" "puppetdb" "--chdir" "$dir" "--realname" "puppetdb" "--operating-system" "$os" "--name" "openvoxdb" "--package-version" "8.9.0" "--release" "1" "--platform-version" "8")
 if [ -n "$os_version" ]; then params+=("--os-version" "$os_version"); fi
 if [ -n "$os_dist" ]; then params+=("--dist" "$os_dist"); fi
 
-params+=('--description' "$(printf "Vox Pupuli puppetdb\nContains: OpenVox-integrated catalog and fact storage (puppetlabs/puppetdb 7.21.2,org.bouncycastle/bcpkix-jdk18on 1.74,org.clojure/clojure 1.11.2,com.zaxxer/HikariCP 2.7.4,puppetlabs/puppetdb 7.21.2)")")
+params+=('--description' "$(printf "Vox Pupuli puppetdb\nContains: OpenVox-integrated catalog and fact storage (puppetlabs/puppetdb 8.9.0,org.bouncycastle/bcpkix-jdk18on 1.78.1,org.clojure/clojure 1.11.2,puppetlabs/puppetdb 8.9.0)")")
 
 DESTDIR="$basepath/termini" bash install.sh termini
 params+=('--build-termini')
 params+=('--termini-chdir' "$basepath/termini")
 termini_description='Termini for puppetdb\nContains terminus for:'
 
-termini_description+='puppetdb (version 7.21.2)'
+termini_description+='puppetdb (version 8.9.0)'
 
 params+=('--termini-description' "$(printf "$termini_description")")
 
@@ -139,14 +139,14 @@ params+=('--termini-description' "$(printf "$termini_description")")
 if [[ "$os" = 'el' || "$os" = 'sles' || "$os" = 'fedora' || "$os" = 'redhatfips' || "$os" = 'amazon' ]]; then
         # pull in rpm dependencies
                         params+=("--additional-dependency")
-                params+=("openvox-agent >= 7.35.0")
+                params+=("openvox-agent >= 8.11.0")
                 # get rpm install trigger scripts
                 # get rpm upgrade trigger scripts
                 : # Need something in case there are no additional dependencies
 else
         # if we aren't an rpm, pull in deb dependencies
                         params+=("--additional-dependency")
-                params+=("openvox-agent (>= 7.35.0)")
+                params+=("openvox-agent (>= 8.11.0)")
                                         : # Need something in case there are no additional dependencies
 fi
 
